nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Dirclr

Struct Dirclr 

#[repr(transparent)]
pub struct Dirclr(pub u32);
Clear pin direction bits for port

Tuple Fields

0: u32

Implementations

Source

impl Dirclr

pub const fn dirclrp(&self) -> u32

Clear direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = No operation. 1 = Clear direction bit.

pub const fn set_dirclrp(&mut self, val: u32)

Clear direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = No operation. 1 = Clear direction bit.