nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Dirnot

Struct Dirnot 

#[repr(transparent)]
pub struct Dirnot(pub u32);
Toggle pin direction bits for port

Tuple Fields

0: u32

Implementations

Source

impl Dirnot

pub const fn dirnotp(&self) -> u32

Toggle direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = no operation. 1 = Toggle direction bit.

pub const fn set_dirnotp(&mut self, val: u32)

Toggle direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = no operation. 1 = Toggle direction bit.