#[repr(transparent)]pub struct Dirset(pub u32);Expand description
Set pin direction bits for port
Tuple Fields
0: u32Implementations
Sourceimpl Dirset
impl Dirset
Sourcepub const fn dirsetp(&self) -> u32
pub const fn dirsetp(&self) -> u32
Set direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = No operation. 1 = Set direction bit.
Sourcepub const fn set_dirsetp(&mut self, val: u32)
pub const fn set_dirsetp(&mut self, val: u32)
Set direction bits (bit 0 = PIOn_0, bit 1 = PIOn_1, etc.). Supported pins depends on the specific device and package. 0 = No operation. 1 = Set direction bit.