nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Intedg

Struct Intedg 

#[repr(transparent)]
pub struct Intedg(pub u32);
choose edge or level for interrupt

Tuple Fields

0: u32

Implementations

Source

impl Intedg

pub const fn edge(&self) -> Edge

choose level or edge based detection for each pin(bit0 for pion_0, bit1 for pion_1, etc)

pub const fn set_edge(&mut self, val: Edge)

choose level or edge based detection for each pin(bit0 for pion_0, bit1 for pion_1, etc)